@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -73,7 +74,7 @@ static gboolean
 timed_exit_cb (void)
 {
         gtk_main_quit ();
-        return FALSE;
+        return G_SOURCE_REMOVE;
 }
 
 static DBusGProxy *
@@ -444,9 +445,11 @@ parse_args (int *argc, char ***argv)
             g_setenv ("G_MESSAGES_DEBUG", "all", FALSE);
 }
 
-static void debug_changed (GSettings *settings, gchar *key, gpointer user_data)
+static void debug_changed (GSettings *settings,
+                           gchar     *key,
+                           gpointer   user_data G_GNUC_UNUSED)
 {
-        debug = g_settings_get_boolean (settings, DEBUG_KEY);
+        debug = g_settings_get_boolean (settings, key);
         if (debug) {
             g_warning ("Enable DEBUG");
             g_setenv ("G_MESSAGES_DEBUG", "all", FALSE);
@@ -545,7 +548,7 @@ main (int argc, char *argv[])
         }
 
         if (do_timed_exit) {
-                g_timeout_add_seconds (30, (GSourceFunc) timed_exit_cb, NULL);
+                g_timeout_add_seconds (30, G_SOURCE_FUNC (timed_exit_cb), NULL);
         }
 
         gtk_main ();
