@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -124,13 +125,7 @@ static int
 compare_priority (MateSettingsPluginInfo *a,
                   MateSettingsPluginInfo *b)
 {
-        int prio_a;
-        int prio_b;
-
-        prio_a = mate_settings_plugin_info_get_priority (a);
-        prio_b = mate_settings_plugin_info_get_priority (b);
-
-        return prio_a - prio_b;
+        return mate_settings_plugin_info_get_priority (a) - mate_settings_plugin_info_get_priority (b);
 }
 
 static void
