@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2008 William Jon McCann <jmccann@redhat.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +50,7 @@
 #define KEY_BOUNCE_KEYS_ENABLED      "bouncekeys-enable"
 #define KEY_SLOW_KEYS_ENABLED        "slowkeys-enable"
 #define KEY_MOUSE_KEYS_ENABLED       "mousekeys-enable"
+#define KEY_CAPSLOCK_BEEP_ENABLED    "capslock-beep-enable"
 
 #define KEY_AT_SCHEMA                   "org.mate.applications-at"
 #define KEY_AT_SCREEN_KEYBOARD_ENABLED  "screen-keyboard-enabled"
@@ -91,6 +93,9 @@ struct MsdA11yPreferencesDialogPrivate
         GtkWidget *sticky_keys_checkbutton;
         GtkWidget *slow_keys_checkbutton;
         GtkWidget *bounce_keys_checkbutton;
+#ifdef HAVE_LIBATSPI
+        GtkWidget *capslock_beep_checkbutton;
+#endif
 
         GtkWidget *large_print_checkbutton;
         GtkWidget *high_contrast_checkbutton;
@@ -122,7 +127,7 @@ msd_a11y_preferences_dialog_class_init (MsdA11yPreferencesDialogClass *klass)
 }
 
 static void
-on_response (MsdA11yPreferencesDialog *dialog,
+on_response (MsdA11yPreferencesDialog *dialog G_GNUC_UNUSED,
              gint                      response_id)
 {
         switch (response_id) {
@@ -322,6 +327,20 @@ config_set_slow_keys (MsdA11yPreferencesDialog *dialog, gboolean enabled)
         g_settings_set_boolean (dialog->priv->settings_a11y, KEY_SLOW_KEYS_ENABLED, enabled);
 }
 
+#ifdef HAVE_LIBATSPI
+static gboolean
+config_get_capslock_beep (MsdA11yPreferencesDialog *dialog, gboolean *is_writable)
+{
+        return config_get_bool (dialog->priv->settings_a11y, KEY_CAPSLOCK_BEEP_ENABLED, is_writable);
+}
+
+static void
+config_set_capslock_beep (MsdA11yPreferencesDialog *dialog, gboolean enabled)
+{
+        g_settings_set_boolean (dialog->priv->settings_a11y, KEY_CAPSLOCK_BEEP_ENABLED, enabled);
+}
+#endif
+
 static gboolean
 config_have_at_gsettings_condition (const char *condition)
 {
@@ -421,6 +440,15 @@ on_slow_keys_checkbutton_toggled (GtkToggleButton          *button,
         config_set_slow_keys (dialog, gtk_toggle_button_get_active (button));
 }
 
+#ifdef HAVE_LIBATSPI
+static void
+on_capslock_beep_checkbutton_toggled (GtkToggleButton          *button,
+                                      MsdA11yPreferencesDialog *dialog)
+{
+        config_set_capslock_beep (dialog, gtk_toggle_button_get_active (button));
+}
+#endif
+
 static void
 on_high_contrast_checkbutton_toggled (GtkToggleButton          *button,
                                       MsdA11yPreferencesDialog *dialog)
@@ -451,7 +479,7 @@ on_at_screen_magnifier_checkbutton_toggled (GtkToggleButton          *button,
 
 static void
 on_large_print_checkbutton_toggled (GtkToggleButton          *button,
-                                    MsdA11yPreferencesDialog *dialog)
+                                    MsdA11yPreferencesDialog *dialog G_GNUC_UNUSED)
 {
         config_set_large_print (gtk_toggle_button_get_active (button));
 }
@@ -492,6 +520,20 @@ ui_set_slow_keys (MsdA11yPreferencesDialog *dialog,
         }
 }
 
+#ifdef HAVE_LIBATSPI
+static void
+ui_set_capslock_beep (MsdA11yPreferencesDialog *dialog,
+                      gboolean                  enabled)
+{
+        gboolean active;
+
+        active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->capslock_beep_checkbutton));
+        if (active != enabled) {
+                gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->capslock_beep_checkbutton), enabled);
+        }
+}
+#endif
+
 static void
 ui_set_high_contrast (MsdA11yPreferencesDialog *dialog,
                       gboolean                  enabled)
@@ -569,6 +611,12 @@ key_changed_cb (GSettings                *settings,
                 gboolean enabled;
                 enabled = g_settings_get_boolean (settings, key);
                 ui_set_slow_keys (dialog, enabled);
+#ifdef HAVE_LIBATSPI
+        } else if (g_strcmp0 (key, KEY_CAPSLOCK_BEEP_ENABLED) == 0) {
+                gboolean enabled;
+                enabled = g_settings_get_boolean (settings, key);
+                ui_set_capslock_beep (dialog, enabled);
+#endif
         } else if (g_strcmp0 (key, KEY_AT_SCREEN_READER_ENABLED) == 0) {
                 gboolean enabled;
                 enabled = g_settings_get_boolean (settings, key);
@@ -633,6 +681,24 @@ setup_dialog (MsdA11yPreferencesDialog *dialog,
                 gtk_widget_set_sensitive (widget, FALSE);
         }
 
+        widget = GTK_WIDGET (gtk_builder_get_object (builder,
+                                                     "capslock_beep_checkbutton"));
+#ifndef HAVE_LIBATSPI
+        gtk_widget_hide (widget);
+        gtk_widget_set_no_show_all (widget, TRUE);
+#else
+        dialog->priv->capslock_beep_checkbutton = widget;
+        g_signal_connect (widget,
+                          "toggled",
+                          G_CALLBACK (on_capslock_beep_checkbutton_toggled),
+                          dialog);
+        enabled = config_get_capslock_beep (dialog, &is_writable);
+        ui_set_capslock_beep (dialog, enabled);
+        if (! is_writable) {
+                gtk_widget_set_sensitive (widget, FALSE);
+        }
+#endif
+
         widget = GTK_WIDGET (gtk_builder_get_object (builder,
                                                      "high_contrast_checkbutton"));
         dialog->priv->high_contrast_checkbutton = widget;
