@@ -3,6 +3,7 @@
  * Copyright (C) 2008 Novell, Inc.
  *
  * Authors: Vincent Untz <vuntz@gnome.org>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -250,9 +251,9 @@ system_timezone_finalize (GObject *obj)
 }
 
 static void
-system_timezone_monitor_changed (GFileMonitor *handle,
-                                 GFile *file,
-                                 GFile *other_file,
+system_timezone_monitor_changed (GFileMonitor *handle G_GNUC_UNUSED,
+                                 GFile *file G_GNUC_UNUSED,
+                                 GFile *other_file G_GNUC_UNUSED,
                                  GFileMonitorEvent event,
                                  gpointer user_data)
 {
