@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2008 Michael J. Chudobiak <mjc@avtechpulse.com>
  * Copyright (C) 2012 Jasmine Hassan <jasmine.aura@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,29 +39,29 @@
 #define THUMB_CACHE_KEY_AGE	"maximum-age"
 #define THUMB_CACHE_KEY_SIZE	"maximum-size"
 
-struct MsdHousekeepingManagerPrivate {
-        guint long_term_cb;
-        guint short_term_cb;
+struct _MsdHousekeepingManager {
+        GObject    parent;
+
+        guint      long_term_cb;
+        guint      short_term_cb;
         GSettings *settings;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (MsdHousekeepingManager, msd_housekeeping_manager, G_TYPE_OBJECT)
+G_DEFINE_TYPE (MsdHousekeepingManager, msd_housekeeping_manager, G_TYPE_OBJECT)
 
 static gpointer manager_object = NULL;
 
-
 typedef struct {
-        glong now;
-        glong max_age;
-        goffset total_size;
-        goffset max_size;
+        GDateTime *now;
+        GTimeSpan  max_age;
+        goffset    total_size;
+        goffset    max_size;
 } PurgeData;
 
-
 typedef struct {
-        time_t  mtime;
-        char   *path;
-        glong   size;
+        GDateTime *mtime;
+        char      *path;
+        glong      size;
 } ThumbData;
 
 
@@ -71,6 +72,7 @@ thumb_data_free (gpointer data)
 
         if (info) {
                 g_free (info->path);
+                g_date_time_unref (info->mtime);
                 g_free (info);
         }
 }
@@ -100,17 +102,20 @@ read_dir_for_purge (const char *path, GList *files)
                                 ThumbData *td;
                                 GFile     *entry;
                                 char      *entry_path;
-                                GTimeVal   mod_time;
 
                                 entry = g_file_get_child (read_path, name);
                                 entry_path = g_file_get_path (entry);
                                 g_object_unref (entry);
 
-                                g_file_info_get_modification_time (info, &mod_time);
-
                                 td = g_new0 (ThumbData, 1);
                                 td->path = entry_path;
-                                td->mtime = mod_time.tv_sec;
+#if GLIB_CHECK_VERSION(2,61,2)
+                                td->mtime = g_file_info_get_modification_date_time (info);
+#else
+                                GTimeVal mod_time_tv;
+                                g_file_info_get_modification_time (info, &mod_time_tv);
+                                td->mtime = g_date_time_new_from_unix_local ((gint64) mod_time_tv.tv_sec);
+#endif
                                 td->size = g_file_info_get_size (info);
 
                                 files = g_list_prepend (files, td);
@@ -127,7 +132,7 @@ read_dir_for_purge (const char *path, GList *files)
 static void
 purge_old_thumbnails (ThumbData *info, PurgeData *purge_data)
 {
-        if ((purge_data->now - info->mtime) > purge_data->max_age) {
+        if (g_date_time_difference (purge_data->now, info->mtime) > purge_data->max_age) {
                 g_unlink (info->path);
                 info->size = 0;
         } else {
@@ -135,10 +140,10 @@ purge_old_thumbnails (ThumbData *info, PurgeData *purge_data)
         }
 }
 
-static int
+static gint
 sort_file_mtime (ThumbData *file1, ThumbData *file2)
 {
-        return file1->mtime - file2->mtime;
+        return g_date_time_compare (file1->mtime, file2->mtime);
 }
 
 static void
@@ -148,12 +153,11 @@ purge_thumbnail_cache (MsdHousekeepingManager *manager)
         char      *path;
         GList     *files;
         PurgeData  purge_data;
-        GTimeVal   current_time;
 
         g_debug ("housekeeping: checking thumbnail cache size and freshness");
 
-        purge_data.max_age = g_settings_get_int (manager->priv->settings, THUMB_CACHE_KEY_AGE) * 24 * 60 * 60;
-        purge_data.max_size = g_settings_get_int (manager->priv->settings, THUMB_CACHE_KEY_SIZE) * 1024 * 1024;
+        purge_data.max_age = g_settings_get_int (manager->settings, THUMB_CACHE_KEY_AGE) * G_TIME_SPAN_DAY;
+        purge_data.max_size = g_settings_get_int (manager->settings, THUMB_CACHE_KEY_SIZE) * 1024 * 1024;
 
         /* if both are set to -1, we don't need to read anything */
         if ((purge_data.max_age < 0) && (purge_data.max_size < 0))
@@ -181,9 +185,7 @@ purge_thumbnail_cache (MsdHousekeepingManager *manager)
         files = read_dir_for_purge (path, files);
         g_free (path);
 
-        g_get_current_time (&current_time);
-
-        purge_data.now = current_time.tv_sec;
+        purge_data.now = g_date_time_new_now_local ();
         purge_data.total_size = 0;
 
         if (purge_data.max_age >= 0)
@@ -199,8 +201,8 @@ purge_thumbnail_cache (MsdHousekeepingManager *manager)
                 }
         }
 
-        g_list_foreach (files, (GFunc) thumb_data_free, NULL);
-        g_list_free (files);
+        g_list_free_full (files, thumb_data_free);
+        g_date_time_unref (purge_data.now);
 }
 
 static gboolean
@@ -214,25 +216,25 @@ static gboolean
 do_cleanup_once (MsdHousekeepingManager *manager)
 {
         do_cleanup (manager);
-        manager->priv->short_term_cb = 0;
+        manager->short_term_cb = 0;
         return FALSE;
 }
 
 static void
 do_cleanup_soon (MsdHousekeepingManager *manager)
 {
-        if (manager->priv->short_term_cb == 0) {
+        if (manager->short_term_cb == 0) {
                 g_debug ("housekeeping: will tidy up in 2 minutes");
-                manager->priv->short_term_cb = g_timeout_add_seconds (INTERVAL_TWO_MINUTES,
+                manager->short_term_cb = g_timeout_add_seconds (INTERVAL_TWO_MINUTES,
                                                (GSourceFunc) do_cleanup_once,
                                                manager);
         }
 }
 
 static void
-settings_changed_callback (GSettings              *settings,
-			   const char             *key,
-			   MsdHousekeepingManager *manager)
+settings_changed_callback (GSettings              *settings G_GNUC_UNUSED,
+                           const char             *key G_GNUC_UNUSED,
+                           MsdHousekeepingManager *manager)
 {
         do_cleanup_soon (manager);
 }
@@ -246,16 +248,16 @@ msd_housekeeping_manager_start (MsdHousekeepingManager *manager,
 
         msd_ldsm_setup (FALSE);
 
-        manager->priv->settings = g_settings_new (THUMB_CACHE_SCHEMA);
+        manager->settings = g_settings_new (THUMB_CACHE_SCHEMA);
 
-	g_signal_connect (manager->priv->settings, "changed",
-			  G_CALLBACK (settings_changed_callback), manager);
+        g_signal_connect (manager->settings, "changed",
+                          G_CALLBACK (settings_changed_callback), manager);
 
         /* Clean once, a few minutes after start-up */
         do_cleanup_soon (manager);
 
         /* Clean periodically, on a daily basis. */
-        manager->priv->long_term_cb = g_timeout_add_seconds (INTERVAL_ONCE_A_DAY,
+        manager->long_term_cb = g_timeout_add_seconds (INTERVAL_ONCE_A_DAY,
                                       (GSourceFunc) do_cleanup,
                                       manager);
         mate_settings_profile_end (NULL);
@@ -263,33 +265,38 @@ msd_housekeeping_manager_start (MsdHousekeepingManager *manager,
         return TRUE;
 }
 
+static void
+msd_housekeeping_manager_finalize (GObject *object)
+{
+        msd_housekeeping_manager_stop (MSD_HOUSEKEEPING_MANAGER (object));
+        G_OBJECT_CLASS (msd_housekeeping_manager_parent_class)->finalize (object);
+}
+
 void
 msd_housekeeping_manager_stop (MsdHousekeepingManager *manager)
 {
-        MsdHousekeepingManagerPrivate *p = manager->priv;
-
         g_debug ("Stopping housekeeping manager");
 
-        if (p->short_term_cb) {
-                g_source_remove (p->short_term_cb);
-                p->short_term_cb = 0;
+        if (manager->short_term_cb) {
+                g_source_remove (manager->short_term_cb);
+                manager->short_term_cb = 0;
         }
 
-        if (p->long_term_cb) {
-                g_source_remove (p->long_term_cb);
-                p->long_term_cb = 0;
+        if (manager->long_term_cb) {
+                g_source_remove (manager->long_term_cb);
+                manager->long_term_cb = 0;
 
                 /* Do a clean-up on shutdown if and only if the size or age
                  * limits have been set to a paranoid level of cleaning (zero)
                  */
-                if ((g_settings_get_int (p->settings, THUMB_CACHE_KEY_AGE) == 0) ||
-                    (g_settings_get_int (p->settings, THUMB_CACHE_KEY_SIZE) == 0)) {
+                if ((g_settings_get_int (manager->settings, THUMB_CACHE_KEY_AGE) == 0) ||
+                    (g_settings_get_int (manager->settings, THUMB_CACHE_KEY_SIZE) == 0)) {
                         do_cleanup (manager);
                 }
         }
 
-       	g_object_unref (p->settings);
-       	p->settings = NULL;
+        g_object_unref (manager->settings);
+        manager->settings = NULL;
 
         msd_ldsm_clean ();
 }
@@ -297,12 +304,14 @@ msd_housekeeping_manager_stop (MsdHousekeepingManager *manager)
 static void
 msd_housekeeping_manager_class_init (MsdHousekeepingManagerClass *klass)
 {
+        GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+        object_class->finalize = msd_housekeeping_manager_finalize;
 }
 
 static void
 msd_housekeeping_manager_init (MsdHousekeepingManager *manager)
 {
-        manager->priv = msd_housekeeping_manager_get_instance_private (manager);
 }
 
 MsdHousekeepingManager *
