@@ -2,6 +2,7 @@
  *
  * msd-ldsm-dialog.c
  * Copyright (C) Chris Coulson 2009 <chrisccoulson@googlemail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * msd-ldsm-dialog.c is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -182,8 +183,7 @@ ignore_check_button_toggled_cb (GtkToggleButton *button,
             g_ptr_array_free (array, FALSE);
         }
 
-        g_slist_foreach (ignore_paths, (GFunc) g_free, NULL);
-        g_slist_free (ignore_paths);
+        g_slist_free_full (ignore_paths, g_free);
         g_object_unref (settings);
 }
 
@@ -450,7 +450,7 @@ msd_ldsm_dialog_new (gboolean     other_usable_partitions,
         button_ignore = gtk_dialog_add_button (GTK_DIALOG (dialog),
                                                _("Ignore"),
                                                GTK_RESPONSE_CANCEL);
-        ignore_image = gtk_image_new_from_stock (GTK_STOCK_CANCEL, GTK_ICON_SIZE_BUTTON);
+        ignore_image = gtk_image_new_from_icon_name ("process-stop", GTK_ICON_SIZE_BUTTON);
         gtk_button_set_image (GTK_BUTTON (button_ignore), ignore_image);
 
         gtk_widget_grab_default (button_ignore);
