@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -500,10 +501,10 @@ keybindings_filter (GdkXEvent             *gdk_xevent,
 }
 
 static void
-bindings_callback (DConfClient           *client,
-                   gchar                 *prefix,
-                   GStrv                  changes,
-                   gchar                 *tag,
+bindings_callback (DConfClient           *client G_GNUC_UNUSED,
+                   gchar                 *prefix G_GNUC_UNUSED,
+                   GStrv                  changes G_GNUC_UNUSED,
+                   gchar                 *tag G_GNUC_UNUSED,
                    MsdKeybindingsManager *manager)
 {
         g_debug ("keybindings: received 'changed' signal from dconf");
