@@ -3,6 +3,7 @@
  * Copyright (C) 2001 Udaltsoft
  *
  * Written by Sergey V. Oudaltsov <svu@users.sourceforge.net>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -157,13 +158,15 @@ apply_desktop_settings (void)
 }
 
 static void
-apply_desktop_settings_cb (GSettings *settings, gchar *key, gpointer   user_data)
+apply_desktop_settings_cb (GSettings *settings G_GNUC_UNUSED,
+                           gchar     *key G_GNUC_UNUSED,
+                           gpointer   user_data G_GNUC_UNUSED)
 {
     apply_desktop_settings ();
 }
 
 static void
-popup_menu_launch_capplet ()
+popup_menu_launch_capplet (void)
 {
 	GAppInfo *info;
 	GdkAppLaunchContext *context;
@@ -189,13 +192,14 @@ popup_menu_launch_capplet ()
 }
 
 static void
-show_layout_destroy (GtkWidget * dialog, gint group)
+show_layout_destroy (GtkWidget *dialog G_GNUC_UNUSED,
+                     gint       group)
 {
 	g_hash_table_remove (preview_dialogs, GINT_TO_POINTER (group));
 }
 
 static void
-popup_menu_show_layout ()
+popup_menu_show_layout (void)
 {
 	GtkWidget *dialog;
 	XklEngine *engine = xkl_engine_get_instance (GDK_DISPLAY_XDISPLAY(gdk_display_get_default()));
@@ -228,7 +232,8 @@ popup_menu_show_layout ()
 }
 
 static void
-popup_menu_set_group (GtkMenuItem * item, gpointer param)
+popup_menu_set_group (GtkMenuItem *item G_GNUC_UNUSED,
+                      gpointer     param)
 {
 	gint group_number = GPOINTER_TO_INT (param);
 	XklEngine *engine = matekbd_status_get_xkl_engine ();
@@ -255,7 +260,9 @@ popup_menu_set_group (GtkMenuItem * item, gpointer param)
 }
 
 static void
-status_icon_popup_menu_cb (GtkStatusIcon * icon, guint button, guint time)
+status_icon_popup_menu_cb (GtkStatusIcon *status_icon,
+                           guint          button,
+                           guint          time)
 {
 	GtkWidget *toplevel;
 	GdkScreen *screen;
@@ -285,13 +292,13 @@ status_icon_popup_menu_cb (GtkStatusIcon * icon, guint button, guint time)
 	item =
 	    gtk_menu_item_new_with_mnemonic (_("Keyboard _Preferences"));
 	gtk_widget_show (item);
-	g_signal_connect (item, "activate", popup_menu_launch_capplet,
+	g_signal_connect (item, "activate", G_CALLBACK (popup_menu_launch_capplet),
 			  NULL);
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
 
 	item = gtk_menu_item_new_with_mnemonic (_("Show _Current Layout"));
 	gtk_widget_show (item);
-	g_signal_connect (item, "activate", popup_menu_show_layout, NULL);
+	g_signal_connect (item, "activate", G_CALLBACK (popup_menu_show_layout), NULL);
 	gtk_menu_shell_append (GTK_MENU_SHELL (popup_menu), item);
 
 	for (i = 0; *current_name; i++, current_name++) {
@@ -326,11 +333,11 @@ status_icon_popup_menu_cb (GtkStatusIcon * icon, guint button, guint time)
 
 	gtk_menu_popup (popup_menu, NULL, NULL,
 			gtk_status_icon_position_menu,
-			(gpointer) icon, button, time);
+			(gpointer) status_icon, button, time);
 }
 
 static void
-show_hide_icon ()
+show_hide_icon (void)
 {
 	if (g_strv_length (current_kbd_config.layouts_variants) > 1) {
 		if (icon == NULL) {
@@ -471,7 +478,9 @@ apply_xkb_settings (void)
 }
 
 static void
-apply_xkb_settings_cb (GSettings *settings, gchar *key, gpointer   user_data)
+apply_xkb_settings_cb (GSettings *settings G_GNUC_UNUSED,
+                       gchar     *key G_GNUC_UNUSED,
+                       gpointer   user_data G_GNUC_UNUSED)
 {
     apply_xkb_settings ();
 }
@@ -496,8 +505,11 @@ msd_keyboard_xkb_set_post_activation_callback (PostActivationCallback fun,
 }
 
 static GdkFilterReturn
-msd_keyboard_xkb_evt_filter (GdkXEvent * xev, GdkEvent * event)
+msd_keyboard_xkb_evt_filter (GdkXEvent *xev,
+                             GdkEvent  *event,
+                             gpointer   data)
 {
+	(void) data;
 	XEvent *xevent = (XEvent *) xev;
 	xkl_engine_filter_events (xkl_engine, xevent);
 	return GDK_FILTER_CONTINUE;
@@ -505,14 +517,14 @@ msd_keyboard_xkb_evt_filter (GdkXEvent * xev, GdkEvent * event)
 
 /* When new Keyboard is plugged in - reload the settings */
 static void
-msd_keyboard_new_device (XklEngine * engine)
+msd_keyboard_new_device (XklEngine * engine G_GNUC_UNUSED)
 {
 	apply_desktop_settings ();
 	apply_xkb_settings ();
 }
 
 static void
-msd_keyboard_update_indicator_icons ()
+msd_keyboard_update_indicator_icons (void)
 {
 	Bool state;
 	int new_state, i;
@@ -543,8 +555,10 @@ msd_keyboard_update_indicator_icons ()
 }
 
 static void
-msd_keyboard_state_changed (XklEngine * engine, XklEngineStateChange type,
-			    gint new_group, gboolean restore)
+msd_keyboard_state_changed (XklEngine           *engine G_GNUC_UNUSED,
+                            XklEngineStateChange type,
+                            gint                 new_group,
+                            gboolean             restore)
 {
 	xkl_debug (160,
 		   "State changed: type %d, new group: %d, restore: %d.\n",
@@ -609,8 +623,7 @@ msd_keyboard_xkb_init (MsdKeyboardManager * kbd_manager)
 		g_signal_connect (settings_kbd, "changed",
 		                  G_CALLBACK (apply_xkb_settings_cb), NULL);
 
-		gdk_window_add_filter (NULL, (GdkFilterFunc)
-				       msd_keyboard_xkb_evt_filter, NULL);
+		gdk_window_add_filter (NULL, msd_keyboard_xkb_evt_filter, NULL);
 
 		if (xkl_engine_get_features (xkl_engine) &
 		    XKLF_DEVICE_DISCOVERY)
@@ -663,8 +676,7 @@ msd_keyboard_xkb_shutdown (void)
 				XKLL_MANAGE_LAYOUTS |
 				XKLL_MANAGE_WINDOW_STATES);
 
-	gdk_window_remove_filter (NULL, (GdkFilterFunc)
-				  msd_keyboard_xkb_evt_filter, NULL);
+	gdk_window_remove_filter (NULL, msd_keyboard_xkb_evt_filter, NULL);
 
 	if (settings_desktop != NULL) {
 		g_object_unref (settings_desktop);
