@@ -1,6 +1,8 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2014 Michal Ratajsky <michal.ratajsky@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,11 +23,10 @@
 #ifndef __MSD_MEDIA_KEYS_MANAGER_H
 #define __MSD_MEDIA_KEYS_MANAGER_H
 
+#include <glib.h>
 #include <glib-object.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+G_BEGIN_DECLS
 
 #define MSD_TYPE_MEDIA_KEYS_MANAGER         (msd_media_keys_manager_get_type ())
 #define MSD_MEDIA_KEYS_MANAGER(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), MSD_TYPE_MEDIA_KEYS_MANAGER, MsdMediaKeysManager))
@@ -34,21 +35,23 @@ extern "C" {
 #define MSD_IS_MEDIA_KEYS_MANAGER_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), MSD_TYPE_MEDIA_KEYS_MANAGER))
 #define MSD_MEDIA_KEYS_MANAGER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MSD_TYPE_MEDIA_KEYS_MANAGER, MsdMediaKeysManagerClass))
 
-typedef struct MsdMediaKeysManagerPrivate MsdMediaKeysManagerPrivate;
+typedef struct _MsdMediaKeysManager         MsdMediaKeysManager;
+typedef struct _MsdMediaKeysManagerClass    MsdMediaKeysManagerClass;
+typedef struct _MsdMediaKeysManagerPrivate  MsdMediaKeysManagerPrivate;
 
-typedef struct
+struct _MsdMediaKeysManager
 {
         GObject                     parent;
         MsdMediaKeysManagerPrivate *priv;
-} MsdMediaKeysManager;
+};
 
-typedef struct
+struct _MsdMediaKeysManagerClass
 {
         GObjectClass   parent_class;
         void          (* media_player_key_pressed) (MsdMediaKeysManager *manager,
                                                     const char          *application,
                                                     const char          *key);
-} MsdMediaKeysManagerClass;
+};
 
 GType                 msd_media_keys_manager_get_type                  (void);
 
@@ -65,8 +68,6 @@ gboolean              msd_media_keys_manager_release_media_player_keys (MsdMedia
                                                                         const char          *application,
                                                                         GError             **error);
 
-#ifdef __cplusplus
-}
-#endif
+G_END_DECLS
 
 #endif /* __MSD_MEDIA_KEYS_MANAGER_H */
