@@ -2,6 +2,7 @@
  *
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
  * Copyright (C) 2010,2011 Red Hat, Inc.
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Author: Bastien Nocera <hadess@hadess.net>
  *
@@ -249,9 +250,9 @@ engine_properties_changed (MsdRfkillManager *manager)
 }
 
 static void
-rfkill_changed (CcRfkillGlib     *rfkill,
-		GList            *events,
-		MsdRfkillManager  *manager)
+rfkill_changed (CcRfkillGlib     *rfkill G_GNUC_UNUSED,
+                GList            *events,
+                MsdRfkillManager *manager)
 {
 	GList *l;
         int value;
@@ -519,7 +520,7 @@ sync_wwan_enabled (MsdRfkillManager *manager)
 
 static void
 nm_signal (GDBusProxy *proxy,
-           char       *sender_name,
+           char       *sender_name G_GNUC_UNUSED,
            char       *signal_name,
            GVariant   *parameters,
            gpointer    user_data)
@@ -575,8 +576,8 @@ on_nm_proxy_gotten (GObject      *source,
 
 static void
 sync_wwan_interesting (GDBusObjectManager *object_manager,
-                       GDBusObject        *object,
-                       GDBusInterface     *interface,
+                       GDBusObject        *object G_GNUC_UNUSED,
+                       GDBusInterface     *interface G_GNUC_UNUSED,
                        gpointer            user_data)
 {
         MsdRfkillManager *manager = user_data;
