@@ -2,6 +2,7 @@
  *
  * Copyright (C) 2007 William Jon McCann <mccann@jhu.edu>
  * Copyright (C) 2007, 2008 Red Hat, Inc
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -460,7 +461,9 @@ timeout_cb (gpointer data)
 }
 
 static void
-timeout_response_cb (GtkDialog *dialog, int response_id, gpointer data)
+timeout_response_cb (GtkDialog *dialog G_GNUC_UNUSED,
+                     int        response_id,
+                     gpointer   data)
 {
         TimeoutDialog *timeout = data;
 
@@ -783,7 +786,7 @@ find_best_mode (MateRROutput *output)
         MateRRMode *preferred;
         MateRRMode **modes;
         int best_size;
-        int best_width, best_height, best_rate;
+        int best_rate;
         int i;
         MateRRMode *best_mode;
 
@@ -795,7 +798,7 @@ find_best_mode (MateRROutput *output)
         if (!modes)
                 return NULL;
 
-        best_size = best_width = best_height = best_rate = 0;
+        best_size = best_rate = 0;
         best_mode = NULL;
 
         for (i = 0; modes[i] != NULL; i++) {
@@ -810,8 +813,6 @@ find_best_mode (MateRROutput *output)
 
                 if (size > best_size) {
                         best_size   = size;
-                        best_width  = w;
-                        best_height = h;
                         best_rate   = r;
                         best_mode   = modes[i];
                 } else if (size == best_size) {
@@ -1670,13 +1671,14 @@ run_display_capplet (GtkWidget *widget)
 }
 
 static void
-popup_menu_configure_display_cb (GtkMenuItem *item, gpointer data)
+popup_menu_configure_display_cb (GtkMenuItem *item, gpointer data G_GNUC_UNUSED)
 {
         run_display_capplet (GTK_WIDGET (item));
 }
 
 static void
-status_icon_popup_menu_selection_done_cb (GtkMenuShell *menu_shell, gpointer data)
+status_icon_popup_menu_selection_done_cb (GtkMenuShell *menu_shell G_GNUC_UNUSED,
+                                          gpointer      data)
 {
         MsdXrandrManager *manager = MSD_XRANDR_MANAGER (data);
         struct MsdXrandrManagerPrivate *priv = manager->priv;
@@ -1696,7 +1698,7 @@ status_icon_popup_menu_selection_done_cb (GtkMenuShell *menu_shell, gpointer dat
 #define OUTPUT_TITLE_ITEM_PADDING 4
 
 static void
-title_item_size_allocate_cb (GtkWidget *widget, GtkAllocation *allocation, gpointer data)
+title_item_size_allocate_cb (GtkWidget *widget, GtkAllocation *allocation, gpointer data G_GNUC_UNUSED)
 {
         /* When GtkMenu does size_request on its items, it asks them for their "toggle size",
          * which will be non-zero when there are check/radio items.  GtkMenu remembers
@@ -2047,11 +2049,10 @@ mirror_outputs_cb(GtkCheckMenuItem *item, gpointer data)
         struct MsdXrandrManagerPrivate *priv = manager->priv;
         MateRRScreen *screen = priv->rw_screen;
 
-        if (gtk_check_menu_item_get_active(item)){
-
+        if (gtk_check_menu_item_get_active (item)) {
                 MateRRConfig *config;
-                config = make_clone_setup (screen);
-                if (!config || config == NULL){
+
+                if ((config = make_clone_setup (screen)) == NULL) {
                         error_message (manager, _("Mirroring outputs not supported"), NULL, NULL);
                 }
 
@@ -2325,7 +2326,8 @@ status_icon_popup_menu (MsdXrandrManager *manager, guint button, guint32 timesta
 }
 
 static void
-status_icon_activate_cb (GtkStatusIcon *status_icon, gpointer data)
+status_icon_activate_cb (GtkStatusIcon *status_icon G_GNUC_UNUSED,
+                         gpointer       data)
 {
         MsdXrandrManager *manager = MSD_XRANDR_MANAGER (data);
 
@@ -2334,7 +2336,10 @@ status_icon_activate_cb (GtkStatusIcon *status_icon, gpointer data)
 }
 
 static void
-status_icon_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint32 timestamp, gpointer data)
+status_icon_popup_menu_cb (GtkStatusIcon *status_icon G_GNUC_UNUSED,
+                           guint          button,
+                           guint32        timestamp,
+                           gpointer       data)
 {
         MsdXrandrManager *manager = MSD_XRANDR_MANAGER (data);
 
@@ -2391,7 +2396,7 @@ start_or_stop_icon (MsdXrandrManager *manager)
 }
 
 static void
-on_config_changed (GSettings        *settings,
+on_config_changed (GSettings        *settings G_GNUC_UNUSED,
                    gchar            *key,
                    MsdXrandrManager *manager)
 {
